@@ -35,6 +35,10 @@ class Profile:
         self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=1000000, hot_pixel_threshold=200000
     ):
         self.scans = []
+        try:
+            kk = len(pixel_max)
+        except TypeError:
+            pixel_max = [pixel_max] * len(file_paths)
         for f in file_paths:
             self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max, hot_pixel_threshold=hot_pixel_threshold))
         self.q_vectors = None
